@@ -22,7 +22,7 @@ Requester::Requester()
 {
     Control::start();
 
-    SpecialMailCollectionsRequestJob *rjob = new SpecialMailCollectionsRequestJob(this);
+    auto *rjob = new SpecialMailCollectionsRequestJob(this);
     rjob->requestDefaultCollection(SpecialMailCollections::Outbox);
     connect(rjob, &SpecialMailCollectionsRequestJob::result, this, &Requester::requestResult);
     rjob->start();
